@@ -49,21 +49,21 @@ out = integer(101),
 #define nodenumOfDyakerIntern 1000000
 #define maxdim 5
 
-int AtomlistNext[numofallIntern+1];
-int AtomlistAtom[numofallIntern+1]; 
+int AtomlistNexty[numofallIntern+1];
+int AtomlistAtomy[numofallIntern+1]; 
 /* point to value,..: values in 1,...,atomnum */
 
-int begsSepaNext[atomnumIntern+1];
-int begsSepaBegs[atomnumIntern+1];
-int atomsSepaNext[atomnumIntern+1];
-int atomsSepaAtom[atomnumIntern+1];
+int begsSepaNexty[atomnumIntern+1];
+int begsSepaBegsy[atomnumIntern+1];
+int atomsSepaNexty[atomnumIntern+1];
+int atomsSepaAtomy[atomnumIntern+1];
 
-int begsLeftBoun[atomnumIntern+1];
-int begsRighBoun[atomnumIntern+1];
-int atomsLBounNext[atomnumIntern+1];
-int atomsRBounNext[atomnumIntern+1];
+int begsLeftBouny[atomnumIntern+1];
+int begsRighBouny[atomnumIntern+1];
+int atomsLBounNexty[atomnumIntern+1];
+int atomsRBounNexty[atomnumIntern+1];
 
-int separy[nodenumOfDyakerIntern+1];
+int separyy[nodenumOfDyakerIntern+1];
 
 int low[atomnumIntern+1][maxdim+1];
 int upp[atomnumIntern+1][maxdim+1];
@@ -80,15 +80,8 @@ int tepu;
 */
 
 #include <math.h>
+#include <stdlib.h> 
 
-#define maxn 1001
-#define maxlstnode 100000
-#define maxkernelnode 100000
-
-#define induksiInt 20    /* length(begsSepaNext) */
-#define componumInt 20   /* length(begsSepaNext) */
-#define mmm 20           /* in declevnewCCC, joinsetsC */
-#define sepnummm 40      /* in joinsetsC */
 
 int declevgenCC(int *left,
                 int *right,
@@ -102,7 +95,7 @@ int declevgenCC(int *left,
                 int nodenumOfDyaker,
 	        int terminalnum,
                 int d);
-int listchangeCCC(int totbegSepary,
+int listchangeCCC(int totbegSeparyy,
                   int beg,
                   /*output*/
                   int *sepalkmi,
@@ -189,9 +182,17 @@ double *lapu5)
 
   int totbegSepary;
 
-  int component[maxlstnode+1];
-  int pinoComponent[maxlstnode+1];  /* pointer to component, level,... */
-  int pinoTaso[maxlstnode+1];       /* ordinal of level (pointer to levseq) */
+  /*
+  int component[*numofall+1];
+  int pinoComponent[*numofall+1];  pointer to component, level,... 
+  int pinoTaso[*numofall+1];       ordinal of level (pointer to levseq) 
+  int tobehandled[*nodenumOfDyaker+1], leafloc[*nodenumOfDyaker+1];
+  */
+  int *component = (int *)malloc(sizeof(int) * (*numofall+1));
+  int *pinoComponent = (int *)malloc(sizeof(int) * (*numofall+1));
+  int *pinoTaso = (int *)malloc(sizeof(int) * (*numofall+1));
+  int *tobehandled = (int *)malloc(sizeof(int) * (*nodenumOfDyaker+1));
+  int *leafloc = (int *)malloc(sizeof(int) * (*nodenumOfDyaker+1));
 
   int componum, beghigher, beg, koko, pinind, ind, levind, partlevsetbeg;
   int listEnd, PrevlistEnd;
@@ -200,17 +201,25 @@ double *lapu5)
   int lokalefek;
   int begi, atto, node, curterminalnum;
  
-  int tobehandled[maxkernelnode+1], leafloc[maxkernelnode+1];
-
   /*volume and center calculation*/
   double curvolu, vol, ala, yla;
   int componentnum, zeiger; 
-  double curcente[maxdim+1], newcente[maxdim+1];                
   int atompointer, uppi, lowi;
-
+  /*double curcente[*d+1], newcente[*d+1];*/ 
+  double *curcente = (double *)malloc(sizeof(double) * (*d+1));
+  double *newcente = (double *)malloc(sizeof(double) * (*d+1));
+ 
   /*listchangeCCC*/
   int kokoout[2], begs[atomnumIntern+1];
 
+  if (component == NULL) exit(1); 
+  if (pinoComponent == NULL) exit(1); 
+  if (pinoTaso == NULL) exit(1); 
+  if (tobehandled == NULL) exit(1); 
+  if (leafloc == NULL) exit(1);  
+  if (curcente == NULL) exit(1);  
+  if (newcente == NULL) exit(1);  
+
   /* Initialize upp, low */
 
   for (i=1; i<=*atomnum; i++){
@@ -234,12 +243,12 @@ double *lapu5)
   /* Initilize the lists */
   i=1;
   while (i<=*atomnum){
-    AtomlistAtom[i]=i;
-    AtomlistNext[i]=i+1;
+    AtomlistAtomy[i]=i;
+    AtomlistNexty[i]=i+1;
     i=i+1;
   }
   listEnd=*atomnum;
-  AtomlistNext[listEnd]=0;
+  AtomlistNexty[listEnd]=0;
 
   /* Let us divide the lowest level set to disconnected parts */
 
@@ -247,14 +256,14 @@ double *lapu5)
   terminalnum=*atomnum;
 
   begi=1;
-  atto=AtomlistAtom[begi];
+  atto=AtomlistAtomy[begi];
   while (begi>0){
      if (value[atto]>0){
         node=nodefinder[atto];
         tobehandled[node]=1;
      }    
-     begi=AtomlistNext[begi];
-     atto=AtomlistAtom[begi];
+     begi=AtomlistNexty[begi];
+     atto=AtomlistAtomy[begi];
   }
   curterminalnum=terminalnum;
 
@@ -308,23 +317,23 @@ if (*levnum>1){  while (pinind>=1){
     /* value=kg$value */
 
     while ((runner>0) && (runner<=origiListEnd)){
-      atom=AtomlistAtom[runner];
+      atom=AtomlistAtomy[runner];
       arvo=value[atom];
       if (arvo>=higlev){
 	  listEnd=listEnd+1;    
-	  AtomlistAtom[listEnd]=atom;
-	  AtomlistNext[listEnd]=listEnd+1; 
+	  AtomlistAtomy[listEnd]=atom;
+	  AtomlistNexty[listEnd]=listEnd+1; 
 	  addnum=addnum+1;     
       }
       else{           
           removenum=removenum+1;
       }                                
-      runner=AtomlistNext[runner]; 
+      runner=AtomlistNexty[runner]; 
     }
-    AtomlistNext[listEnd]=0;      /* we have to correct the end to terminate */
+    AtomlistNexty[listEnd]=0;      /* we have to correct the end to terminate */
 
     if (addnum>0){
-      AtomlistNext[PrevlistEnd]=0;
+      AtomlistNexty[PrevlistEnd]=0;
       beghigher=PrevlistEnd+1;
     }
     if (removenum==0){ /* jos leikkaus ei muuta, niin tasoj sailyy samana  */
@@ -342,10 +351,10 @@ if (*levnum>1){  while (pinind>=1){
       begi=beghigher;
       for (ij=1; ij<=*nodenumOfDyaker; ij++) tobehandled[ij]=0;
       while (begi>0){
-          atto=AtomlistAtom[begi];
+          atto=AtomlistAtomy[begi];
           node=nodefinder[atto];
           tobehandled[node]=1;
-          begi=AtomlistNext[begi];
+          begi=AtomlistNexty[begi];
       }
       curterminalnum=addnum;
       terminalnum=addnum;
@@ -370,7 +379,7 @@ if (*levnum>1){  while (pinind>=1){
       /*
       if (globapu2==1){
  for (j=1; j<=100; j++){
-   out[j]=atomsSepaNext[j];
+   out[j]=atomsSepaNexty[j];
  }
       }
       */
@@ -419,7 +428,7 @@ for (i=1; i<=componentnum; i++){
   curvolu=0;
   zeiger=component[i];
   while (zeiger>0){
-     atto=AtomlistAtom[zeiger];
+     atto=AtomlistAtomy[zeiger];
      vol=1;
      for (j=1; j<=*d; j++){
         lowi=inlow[(atto-1)*(*d)+j];  /*[atto][j]*/
@@ -427,7 +436,7 @@ for (i=1; i<=componentnum; i++){
         vol=vol*(uppi-lowi)*step[j];
      }
      curvolu=curvolu+vol;
-     zeiger=AtomlistNext[zeiger];
+     zeiger=AtomlistNexty[zeiger];
   }
   volume[i]=curvolu;
 }
@@ -436,7 +445,7 @@ for (i=1; i<=componentnum; i++){
   for (j=1; j<=*d; j++) curcente[j]=0;
   zeiger=component[i];
   while (zeiger>0){
-     atompointer=AtomlistAtom[zeiger];
+     atompointer=AtomlistAtomy[zeiger];
      for (j=1; j<=*d; j++) newcente[j]=0;
      for (j=1; j<=*d; j++){
         /*calculate 1st volume of d-1 dimensional rectangle where*/
@@ -458,7 +467,7 @@ for (i=1; i<=componentnum; i++){
         newcente[j]=vol*(pow(yla,2)-pow(ala,2))/2;
      }
      for (j=1; j<=*d; j++) curcente[j]=curcente[j]+newcente[j];
-     zeiger=AtomlistNext[zeiger];
+     zeiger=AtomlistNexty[zeiger];
   }
   for (j=1; j<=*d; j++) center[(i-1)*(*d)+j]=curcente[j]/volume[i];
 
@@ -476,11 +485,18 @@ for (i=1; i<=componentnum; i++){
  *numOfAtoms=listEnd;
  
  for (j=1; j<=listEnd; j++){
-     AtomlistAtomOut[j]=AtomlistAtom[j];
+     AtomlistAtomOut[j]=AtomlistAtomy[j];
      AtomlistNextOut[j]=AtomlistNext[j];
  }
  */
  
+  free(component); 
+  free(pinoComponent); 
+  free(pinoTaso); 
+  free(tobehandled); 
+  free(leafloc);  
+  free(curcente);  
+  free(newcente);  
 
 }
 
@@ -505,27 +521,40 @@ int declevgenCC(int *left,
                 int d)
 
 {
+    /*
+ int nextFloor[terminalnum+1];
+ int currFloor[terminalnum+1];
+ int already[nodenumOfDyaker+1];
+    */
+ int *nextFloor = (int *)malloc(sizeof(int) * (terminalnum+1));
+ int *currFloor = (int *)malloc(sizeof(int) * (terminalnum+1));
+ int *already = (int *)malloc(sizeof(int) * (nodenumOfDyaker+1));
+ 
  int i, lkm, nodee, note, nodelkm;
  int Lempty, Rempty;
  int leftbeg, rightbeg, direction, akku, apu3;
  int direktiooni, poiju, prevpoiju, aatto, thisnoteempty;
  double splittiini;
 
+ if (nextFloor == NULL) exit(1);
+ if (currFloor == NULL) exit(1);
+ if (already == NULL) exit(1);
+
   /* Initialize the global variables */
 
   for (i=1; i<=atomnumIntern; i++){
-    begsSepaNext[i]=0;
-    begsSepaBegs[i]=0;
-    atomsSepaNext[i]=0;
-    atomsSepaAtom[i]=0;
+    begsSepaNexty[i]=0;
+    begsSepaBegsy[i]=0;
+    atomsSepaNexty[i]=0;
+    atomsSepaAtomy[i]=0;
 
-    begsLeftBoun[i]=0;
-    begsRighBoun[i]=0;
-    atomsLBounNext[i]=0;
-    atomsRBounNext[i]=0;
+    begsLeftBouny[i]=0;
+    begsRighBouny[i]=0;
+    atomsLBounNexty[i]=0;
+    atomsRBounNexty[i]=0;
   }
 
-  for (i=1; i<=nodenumOfDyakerIntern; i++) separy[i]=0;
+  for (i=1; i<=nodenumOfDyakerIntern; i++) separyy[i]=0;
 
 
   nodelkm=nodenumOfDyaker;
@@ -541,14 +570,14 @@ int declevgenCC(int *left,
           tobehandled[parent[nodee]]=1;
 
           lkm=lkm+1;
-          separy[nodee]=lkm;
-          atomsSepaAtom[lkm]=infopointer[nodee];
+          separyy[nodee]=lkm;
+          atomsSepaAtomy[lkm]=infopointer[nodee];
 
-          begsSepaBegs[lkm]=lkm;
+          begsSepaBegsy[lkm]=lkm;
 
           /*
           obs: we need not change
-          begsSepaNext, atomsSepaNext, atomsLBounNext, atomsRBounNext
+          begsSepaNexty, atomsSepaNexty, atomsLBounNexty, atomsRBounNext
           since at the beginning set consist only one member:
           pointer is always 0, since we do not have followers
 	  */
@@ -561,7 +590,7 @@ int declevgenCC(int *left,
 	  leftbeg=left[nodee];
 	  rightbeg=right[nodee];
 
-          if ((leftbeg==0) || (separy[leftbeg]==0)){
+          if ((leftbeg==0) || (separyy[leftbeg]==0)){
 	    /*if left child does not exist*/
 
 	    /*
@@ -570,7 +599,7 @@ int declevgenCC(int *left,
             that leftbeg>0 but left child does not exist
 	    */
            
-	    separy[nodee]=separy[rightbeg];
+	    separyy[nodee]=separyy[rightbeg];
 
             /*
             we need that all lists contain as many members
@@ -580,10 +609,10 @@ int declevgenCC(int *left,
 
           }
           else{ /* eka else */
-            if ((rightbeg==0) || (separy[rightbeg]==0)){
+            if ((rightbeg==0) || (separyy[rightbeg]==0)){
 	   	/* right child does not exist */
     
-		separy[nodee]=separy[leftbeg];
+		separyy[nodee]=separyy[leftbeg];
                       
                 /*
                 left boundary stays same as for leftbeg
@@ -603,61 +632,61 @@ int declevgenCC(int *left,
                 */
 
 		Lempty=1;
-		note=separy[rightbeg];
+		note=separyy[rightbeg];
                     while (note>0){
                         thisnoteempty=1;
 
-                        poiju=begsSepaBegs[note];
+                        poiju=begsSepaBegsy[note];
                         prevpoiju=poiju;
                         while (poiju>0){
-		           aatto=atomsSepaAtom[poiju];
+		           aatto=atomsSepaAtomy[poiju];
                            if (splittiini>=low[aatto][direktiooni]){
                                /* this atom belongs to boundary */
                                if (thisnoteempty==1){
                                    /* poiju is the 1st non-empty */
-                                   begsLeftBoun[note]=poiju;
+                                   begsLeftBouny[note]=poiju;
                                }                
                                Lempty=0;
-                               atomsLBounNext[prevpoiju]=poiju;    
-                               atomsLBounNext[poiju]=0;
+                               atomsLBounNexty[prevpoiju]=poiju;    
+                               atomsLBounNexty[poiju]=0;
                                prevpoiju=poiju;
 
                                thisnoteempty=0;
                            }
-                           poiju=atomsSepaNext[poiju];
+                           poiju=atomsSepaNexty[poiju];
                         }
-                        if (thisnoteempty) begsLeftBoun[note]=0;
-                        note=begsSepaNext[note];
+                        if (thisnoteempty) begsLeftBouny[note]=0;
+                        note=begsSepaNexty[note];
                      }
 
                     /* right boundary of left child */
 
 		    Rempty=1;
-		    note=separy[leftbeg];
+		    note=separyy[leftbeg];
                      while (note>0){
 			 thisnoteempty=1;
                        
-			 poiju=begsSepaBegs[note];
+			 poiju=begsSepaBegsy[note];
 			 prevpoiju=poiju;
                          while (poiju>0){
-			    aatto=atomsSepaAtom[poiju];
+			    aatto=atomsSepaAtomy[poiju];
                             if (splittiini<=upp[aatto][direktiooni]){
                                /* this atom belongs to boundary */
                                if (thisnoteempty==1){
                                    /* poiju is the 1st non-empty */
-                                   begsRighBoun[note]=poiju;
+                                   begsRighBouny[note]=poiju;
                                }                
                                Rempty=0;
-                               atomsRBounNext[prevpoiju]=poiju;    
-                               atomsRBounNext[poiju]=0;
+                               atomsRBounNexty[prevpoiju]=poiju;    
+                               atomsRBounNexty[poiju]=0;
                                prevpoiju=poiju;
                            
                                thisnoteempty=0;
                            }
-                           poiju=atomsSepaNext[poiju];
+                           poiju=atomsSepaNexty[poiju];
                         }
-                        if (thisnoteempty) begsRighBoun[note]=0;
-                        note=begsSepaNext[note];
+                        if (thisnoteempty) begsRighBouny[note]=0;
+                        note=begsSepaNexty[note];
                      }
     
 	             /* check whether one of boundaries is empty */
@@ -668,13 +697,13 @@ int declevgenCC(int *left,
                         
 			 /* concatenating separate parts */
                        
-			 akku=separy[leftbeg];
+			 akku=separyy[leftbeg];
                  
-			 begsSepaNext[akku]=separy[rightbeg]; 
+			 begsSepaNexty[akku]=separyy[rightbeg]; 
                          /* concatenate list of separate sets */
 
-			 separy[nodee]=separy[leftbeg];
-			 akku=separy[rightbeg];
+			 separyy[nodee]=separyy[leftbeg];
+			 akku=separyy[rightbeg];
                           
                         /* left boundaries of sets in right child are empty */
                         /* end of concatenating */
@@ -690,13 +719,13 @@ int declevgenCC(int *left,
                                           rightbeg,
                                           direction,
                                           d);
-			 separy[nodee]=apu3;
+			 separyy[nodee]=apu3;
 
 		     /*
-                     jc=joincongen(leftbeg,rightbeg,separy,
-                     begsSepaNext,begsSepaBegs,begsLeftBoun,begsRighBoun,
-                     atomsSepaNext,atomsSepaAtom,atomsLBounNext,
-                     atomsRBounNext,
+                     jc=joincongen(leftbeg,rightbeg,separyy,
+                     begsSepaNexty,begsSepaBegsy,begsLeftBouny,begsRighBouny,
+                     atomsSepaNexty,atomsSepaAtomy,atomsLBounNexty,
+                     atomsRBounNexty,
                      direction,low,upp)   
 		     */
 
@@ -707,15 +736,18 @@ int declevgenCC(int *left,
       nodee=nodee-1;
 }
 
-  return separy[1];
+  return separyy[1];
 
 /*
-totbegSepary=separy[1],
-begsSepaNext=begsSepaNext,
-begsSepaBegs=begsSepaBegs,
-atomsSepaNext=atomsSepaNext,
-atomsSepaAtom=atomsSepaAtom
+totbegSepary=separyy[1],
+begsSepaNexty=begsSepaNexty,
+begsSepaBegsy=begsSepaBegsy,
+atomsSepaNexty=atomsSepaNexty,
+atomsSepaAtomy=atomsSepaAtomy
 */
+ free(nextFloor);
+ free(currFloor);
+ free(already);
 
 }
 
@@ -742,22 +774,22 @@ int listchangeCCC(int totbegSepary,
  sepalkm=0;
  while (runnerBegs>0){
    sepalkm=sepalkm+1;
-   runnerAtoms=begsSepaBegs[runnerBegs];
+   runnerAtoms=begsSepaBegsy[runnerBegs];
    begs[sepalkm]=runnerOrigi;
    /* first step (in order to get also runnerOrigiprev to play) */
-   AtomlistAtom[runnerOrigi]=atomsSepaAtom[runnerAtoms];
+   AtomlistAtomy[runnerOrigi]=atomsSepaAtomy[runnerAtoms];
    runnerOrigiprev=runnerOrigi;
-   runnerOrigi=AtomlistNext[runnerOrigi];
-   runnerAtoms=atomsSepaNext[runnerAtoms];
+   runnerOrigi=AtomlistNexty[runnerOrigi];
+   runnerAtoms=atomsSepaNexty[runnerAtoms];
 
    while (runnerAtoms>0){
-     AtomlistAtom[runnerOrigi]=atomsSepaAtom[runnerAtoms];
+     AtomlistAtomy[runnerOrigi]=atomsSepaAtomy[runnerAtoms];
      runnerOrigiprev=runnerOrigi;
-     runnerOrigi=AtomlistNext[runnerOrigi];
-     runnerAtoms=atomsSepaNext[runnerAtoms];
+     runnerOrigi=AtomlistNexty[runnerOrigi];
+     runnerAtoms=atomsSepaNexty[runnerAtoms];
    }
-   AtomlistNext[runnerOrigiprev]=0;  /* mark the end of the list */
-   runnerBegs=begsSepaNext[runnerBegs];
+   AtomlistNexty[runnerOrigiprev]=0;  /* mark the end of the list */
+   runnerBegs=begsSepaNexty[runnerBegs];
  }
  /* begs=begs[1:sepalkm] */
 
@@ -793,9 +825,11 @@ int findleafs(int *left,
               int *leafloc)
 {
 
- int pino[maxkernelnode+1], apu, i, pinin, cur;
+ int apu, i, pinin, cur;
+ /*   int pino[itemnum+1];  */   /* itemnum=length(left) */
+ int *pino = (int *)malloc(sizeof(int) * (itemnum+1));
 
- /* itemnum=length(left) */
+ if (pino == NULL) exit(1);
 
  for (i=1; i<=itemnum; i++) leafloc[i]=-1;
 
@@ -819,6 +853,9 @@ int findleafs(int *left,
  }
  apu=1;
  return apu;
+
+ free(pino);
+
 }
 
 
@@ -830,14 +867,14 @@ see: joincongen.R
 
 INPUT: 
 leftbeg,rightbeg,direction,d
-separy,
-begsSepaNext,begsSepaBegs,begsLeftBoun,begsRighBoun,
-atomsSepaNext,atomsSepaAtom,atomsLBounNext,atomsRBounNext,
+separyy,
+begsSepaNexty,begsSepaBegsy,begsLeftBouny,begsRighBouny,
+atomsSepaNexty,atomsSepaAtomy,atomsLBounNexty,atomsRBounNexty,
 low,upp
 OUTPUT:
 totbegSepary, 
-begsSepaNext, begsSepaBegs, begsLeftBoun, begsRighBoun,
-atomsSepaNext,                atomsLBounNext, atomsRBounNext
+begsSepaNexty, begsSepaBegsy, begsLeftBouny, begsRighBouny,
+atomsSepaNexty,                atomsLBounNexty, atomsRBounNexty
 */
 
 
@@ -848,27 +885,47 @@ int joincongenC(int leftbeg,
 {
 
   int apu, i;
+  int induksiInt=20;    /* length(begsSepaNexty) */
+  int componumInt=20;   /* length(begsSepaNexty) */
 
   /*startpointsC*/
+  /*
   int startpointsS[induksiInt+1];
   int startpointsB[induksiInt+1];
   int startpointsNewBleft[induksiInt+1];
   int startpointsNewBright[induksiInt+1];
+  */
+  int *startpointsS = (int *)malloc(sizeof(int) * (induksiInt+1));
+  int *startpointsB = (int *)malloc(sizeof(int) * (induksiInt+1));
+  int *startpointsNewBleft = (int *)malloc(sizeof(int) * (induksiInt+1));
+  int *startpointsNewBright = (int *)malloc(sizeof(int) * (induksiInt+1));
+
   int m, mleft, mright;
   int mleftout[2], mrightout[2];
 
   /*makelinksC*/
   /*int linkit[componumInt+1][componumInt+1];*/
+  /*
   int outlinkit[1+componumInt*componumInt];
+  int outtulos[componumInt+1];
+  */
+  int *outlinkit = (int *)malloc(sizeof(int) * (1+componumInt*componumInt));
+  int *outtulos = (int *)malloc(sizeof(int) * (componumInt+1));
 
   /*declevnewCCC*/
-  int sepnum, tulospit[2], outtulos[componumInt+1];
+ int sepnum, tulospit[2];
   /*int res[componumInt+1][componumInt+1];*/
   /*int inlinkit[1+componumInt*componumInt];*/
 
   /*joinsetsC*/
   int Totalbeg, Totalbegout[2];
 
+  if (startpointsS == NULL) exit(1);
+  if (startpointsB == NULL) exit(1);
+  if (startpointsNewBleft == NULL) exit(1);
+  if (startpointsNewBright == NULL) exit(1);
+  if (outlinkit == NULL) exit(1);
+  if (outtulos == NULL) exit(1);
 
   /* 1. new boundary: left bound. of left child, right b. of right child */
 
@@ -941,6 +998,13 @@ int joincongenC(int leftbeg,
 
   return Totalbeg;
 
+  free(startpointsS);
+  free(startpointsB);
+  free(startpointsNewBleft);
+  free(startpointsNewBright);
+  free(outlinkit);
+  free(outtulos);
+
 }
 
 
@@ -958,10 +1022,32 @@ int declevnewCCC(int m, int *inlinkit,
                  int *tulospit, 
                  int *outtulos)  
 {
-  int pino[mmm+1], pinind; 
+  int pinind; 
     /*pinoon laitetaan aina jos koskettaa, max kosketuksia m*/
-  int i, j, k, curleima, merkatut[mmm+1], curpallo, touch;  
-  int linksit[mmm+1][mmm+1], tulos[mmm+1][mmm+1], apu;
+  int i, j, k, curleima, curpallo, touch;  
+  int apu;
+  /*
+  int pino[m+1], merkatut[m+1]; 
+  int linksit[m+1][m+1], tulos[m+1][m+1];
+  */
+ int *pino = (int *)malloc(sizeof(int) * (m+1));
+ int *merkatut = (int *)malloc(sizeof(int) * (m+1));
+ int ** linksit;
+ int ** tulos;
+ linksit = (int **)malloc((m+1) * sizeof(int *));
+ tulos = (int **)malloc((m+1) * sizeof(int *));
+ if (NULL == linksit) exit(1);
+ for (i = 0; i <= m; i++) {
+      linksit[i] = (int *)malloc((m+1) * sizeof(int));
+      if (NULL == linksit[i]) exit(1);
+ }
+ if (NULL == tulos) exit(1);
+ for (i = 0; i <= m; i++) {
+      tulos[i] = (int *)malloc((m+1) * sizeof(int));
+      if (NULL == tulos[i]) exit(1);
+ }
+ if (pino == NULL) exit(1); 
+ if (merkatut == NULL) exit(1); 
 
   /* initialize */
   for (k=1; k<=m; k++) merkatut[k]=0;
@@ -1014,6 +1100,13 @@ int declevnewCCC(int m, int *inlinkit,
   apu=curleima-1;
   return apu;
 
+ free(pino); 
+ free(merkatut); 
+ for(i = 0; i <= m; i++) free(linksit[i]);
+ free(linksit);
+ for(i = 0; i <= m; i++) free(tulos[i]);
+ free(tulos);
+
 }
 
 
@@ -1031,29 +1124,29 @@ int startpointsC(int leftbeg, int rightbeg,
   int induksi, anfang, m, ml, mr;
 
   induksi=1;
-  anfang=separy[leftbeg];
+  anfang=separyy[leftbeg];
   startpointsS[induksi]=anfang;
-  startpointsB[induksi]=begsRighBoun[anfang];
-  startpointsNewBleft[induksi]=begsLeftBoun[anfang];
-  while (begsSepaNext[anfang]>0){
-    anfang=begsSepaNext[anfang];
+  startpointsB[induksi]=begsRighBouny[anfang];
+  startpointsNewBleft[induksi]=begsLeftBouny[anfang];
+  while (begsSepaNexty[anfang]>0){
+    anfang=begsSepaNexty[anfang];
     induksi=induksi+1;
-    startpointsS[induksi]=begsSepaBegs[anfang];
-    startpointsB[induksi]=begsRighBoun[anfang];
-    startpointsNewBleft[induksi]=begsLeftBoun[anfang];  
+    startpointsS[induksi]=begsSepaBegsy[anfang];
+    startpointsB[induksi]=begsRighBouny[anfang];
+    startpointsNewBleft[induksi]=begsLeftBouny[anfang];  
   }
   ml=induksi;
   induksi=induksi+1;
-  anfang=separy[rightbeg];
+  anfang=separyy[rightbeg];
   startpointsS[induksi]=anfang;
-  startpointsB[induksi]=begsLeftBoun[anfang];
-  startpointsNewBright[induksi]=begsRighBoun[anfang];
-  while (begsSepaNext[anfang]>0){
-    anfang=begsSepaNext[anfang];
+  startpointsB[induksi]=begsLeftBouny[anfang];
+  startpointsNewBright[induksi]=begsRighBouny[anfang];
+  while (begsSepaNexty[anfang]>0){
+    anfang=begsSepaNexty[anfang];
     induksi=induksi+1;
-    startpointsS[induksi]=begsSepaBegs[anfang];
-    startpointsB[induksi]=begsLeftBoun[anfang];
-    startpointsNewBright[induksi]=begsRighBoun[anfang];  
+    startpointsS[induksi]=begsSepaBegsy[anfang];
+    startpointsB[induksi]=begsLeftBouny[anfang];
+    startpointsNewBright[induksi]=begsRighBouny[anfang];  
   }
   m=induksi;
   mr=m-ml;  
@@ -1079,12 +1172,28 @@ int makelinksC(int mleft, int mright, int direction, int d,
 
   int apu, i, j, k;
   int dodo, re, beg1, beg2, conne;
-  int indelow1[maxdim+1], indelow2[maxdim+1];
-  int indeupp1[maxdim+1], indeupp2[maxdim+1];
+  /*int indelow1[d+1], indelow2[d+1], indeupp1[d+1], indeupp2[d+1];*/
+  int *indelow1 = (int *)malloc(sizeof(int) * (d+1));
+  int *indelow2 = (int *)malloc(sizeof(int) * (d+1));
+  int *indeupp1 = (int *)malloc(sizeof(int) * (d+1));
+  int *indeupp2 = (int *)malloc(sizeof(int) * (d+1));
+
   int begbeg1, begbeg2, atom1, atom2, touch;
 
   int m=mleft+mright;
-  int linkit[mmm+1][mmm+1];
+  /*int linkit[m+1][m+1]; */
+  int ** linkit;
+  linkit = (int **)malloc((m+1) * sizeof(int *));
+  if (NULL == linkit) exit(1);
+  for (i = 0; i <= m; i++) {
+      linkit[i] = (int *)malloc((m+1) * sizeof(int));
+      if (NULL == linkit[i]) exit(1);
+  }
+
+  if (indelow1 == NULL) exit(1);
+  if (indelow2 == NULL) exit(1);
+  if (indeupp1 == NULL) exit(1);
+  if (indeupp2 == NULL) exit(1);
 
   for (i=1; i<=m; i++){
      for (j=1; j<=m; j++){
@@ -1103,8 +1212,8 @@ int makelinksC(int mleft, int mright, int direction, int d,
           while (begbeg1>0){
 	      begbeg2=beg2;
               while (begbeg2>0){
-		  atom1=atomsSepaAtom[begbeg1];
-		  atom2=atomsSepaAtom[begbeg2];
+		  atom1=atomsSepaAtomy[begbeg1];
+		  atom2=atomsSepaAtomy[begbeg2];
 		  for (k=1; k<=d; k++){
                      indelow1[k]=low[atom1][k];
 		     indeupp1[k]=upp[atom1][k];
@@ -1121,9 +1230,9 @@ int makelinksC(int mleft, int mright, int direction, int d,
 	            i=i+1;
                   }                
                   if (touch) conne=1;   /* TRUE */
-                  begbeg2=atomsLBounNext[begbeg2];
+                  begbeg2=atomsLBounNexty[begbeg2];
               }
-              begbeg1=atomsRBounNext[begbeg1];
+              begbeg1=atomsRBounNexty[begbeg1];
           }                
           if (conne) linkit[dodo][re]=1;
           re=re+1;
@@ -1139,8 +1248,8 @@ int makelinksC(int mleft, int mright, int direction, int d,
           while (begbeg1>0){
 	     begbeg2=beg2;
              while (begbeg2>0){
-		 atom1=atomsSepaAtom[begbeg1];
-		 atom2=atomsSepaAtom[begbeg2];
+		 atom1=atomsSepaAtomy[begbeg1];
+		 atom2=atomsSepaAtomy[begbeg2];
                  for (k=1; k<=d; k++){
                      indelow1[k]=low[atom1][k];
 		     indeupp1[k]=upp[atom1][k];
@@ -1157,9 +1266,9 @@ int makelinksC(int mleft, int mright, int direction, int d,
 	            i=i+1;
                  }        
                  if (touch) conne=1;   /* TRUE */
-                 begbeg2=atomsRBounNext[begbeg2];
+                 begbeg2=atomsRBounNexty[begbeg2];
              }
-	     begbeg1=atomsLBounNext[begbeg1];
+	     begbeg1=atomsLBounNexty[begbeg1];
           }                
           if (conne) linkit[dodo][re]=1;
       }
@@ -1174,6 +1283,14 @@ int makelinksC(int mleft, int mright, int direction, int d,
   apu=1;
   return apu;
 
+  free(indelow1);
+  free(indelow2);
+  free(indeupp1);
+  free(indeupp2);
+  for(i = 0; i <= m; i++) free(linkit[i]);
+  free(linkit);
+
+
 }
 
 
@@ -1183,8 +1300,8 @@ int makelinksC(int mleft, int mright, int direction, int d,
 /*
 OutPut:
 
-begsSepaNext, begsSepaBegs, begsLeftBoun, begsRighBoun,
-atomsSepaNext, atomsLBounNext, atomsRBounNext
+begsSepaNexty, begsSepaBegsy, begsLeftBouny, begsRighBouny,
+atomsSepaNexty, atomsLBounNexty, atomsRBounNexty
 */
 
 
@@ -1199,14 +1316,29 @@ int joinsetsC(int leftbeg, int rightbeg, int sepnum, int m,
   int apu, i, j, ii, jj, k, ll;
 
   int len;   /* len=sum(res[i,]) number of sets to be joined */
-  int res[sepnummm][mmm];
   int Totalbeg, tavoite, hiihtaja, nykyinen;
   int laskuri, curre, kL, kR;
  
  /* m=induksiInt */
-  int osoittajaS[mmm+1];  /* make vector of pointers to the begs of sets */
-  int osoittajaNewBleft[mmm+1];
-  int osoittajaNewBright[mmm+1];
+  /*
+  int osoittajaS[m+1];  make vector of pointers to the begs of sets 
+  int osoittajaNewBleft[m+1];
+  int osoittajaNewBright[m+1];
+  int res[sepnum][m];
+  */
+  int *osoittajaS= (int *)malloc(sizeof(int) * (m+1));
+  int *osoittajaNewBleft= (int *)malloc(sizeof(int) * (m+1));
+  int *osoittajaNewBright= (int *)malloc(sizeof(int) * (m+1));
+  int ** res;
+  res = (int **)malloc((sepnum+1) * sizeof(int *));
+  if (NULL == res) exit(1);
+  for (i = 0; i <= m; i++) {
+      res[i] = (int *)malloc((m+1) * sizeof(int));
+      if (NULL == res[i]) exit(1);
+  }
+  if (osoittajaS == NULL) exit(1);
+  if (osoittajaNewBleft == NULL) exit(1);
+  if (osoittajaNewBright == NULL) exit(1);
 
   for (i=1; i<=sepnum; i++){
     for (j=1; j<=m; j++){
@@ -1220,28 +1352,28 @@ int joinsetsC(int leftbeg, int rightbeg, int sepnum, int m,
      osoittajaNewBright[i]=0;
   }
 
- Totalbeg=separy[leftbeg];
+ Totalbeg=separyy[leftbeg];
 
  tavoite=1;
  hiihtaja=Totalbeg;
- while ((begsSepaNext[hiihtaja]>0) && (tavoite<sepnum)){
-     hiihtaja=begsSepaNext[hiihtaja];
+ while ((begsSepaNexty[hiihtaja]>0) && (tavoite<sepnum)){
+     hiihtaja=begsSepaNexty[hiihtaja];
      tavoite=tavoite+1;
  }  
  if (tavoite<sepnum){  /* now hiihtaja points to the end of the first list */
 	               /* join the lists */
-     begsSepaNext[hiihtaja]=separy[rightbeg];
+     begsSepaNexty[hiihtaja]=separyy[rightbeg];
      /* we continue */
-     hiihtaja=separy[rightbeg];
+     hiihtaja=separyy[rightbeg];
      tavoite=tavoite+1;
-     while ((begsSepaNext[hiihtaja]>0) && (tavoite<sepnum)){
-	 hiihtaja=begsSepaNext[hiihtaja];
+     while ((begsSepaNexty[hiihtaja]>0) && (tavoite<sepnum)){
+	 hiihtaja=begsSepaNexty[hiihtaja];
 	 tavoite=tavoite+1;
      }    
-     begsSepaNext[hiihtaja]=0;
+     begsSepaNexty[hiihtaja]=0;
  }
  else{  /* we have reached goal, cut without joining */
-     begsSepaNext[hiihtaja]=0;
+     begsSepaNexty[hiihtaja]=0;
  }
 
 
@@ -1267,28 +1399,28 @@ int joinsetsC(int leftbeg, int rightbeg, int sepnum, int m,
          }    
      }
   
-     /* handle separy */
+     /* handle separyy */
   
-     begsSepaBegs[nykyinen]=osoittajaS[1];   /* always non-zero */
+     begsSepaBegsy[nykyinen]=osoittajaS[1];   /* always non-zero */
      
      k=1;
      while (k<=(len-1)){    
 	 curre=osoittajaS[k];
-         while (atomsSepaNext[curre]>0){ /*find the end*/
-	      curre=atomsSepaNext[curre];
+         while (atomsSepaNexty[curre]>0){ /*find the end*/
+	      curre=atomsSepaNexty[curre];
          }
-         atomsSepaNext[curre]=osoittajaS[k+1];
+         atomsSepaNexty[curre]=osoittajaS[k+1];
 	 k=k+1;
      }
 
 /*
-if ((atomsSepaNext[12]==11) && (globapu2==1)) globapu3=globapu3+1;
+if ((atomsSepaNexty[12]==11) && (globapu2==1)) globapu3=globapu3+1;
 if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
-       apsu1=atomsSepaNext[11];
-       apsu2=atomsSepaNext[12];
-       apsu3=atomsSepaNext[13];
-       apsu4=atomsSepaNext[14];
-       apsu5=atomsSepaNext[15];
+       apsu1=atomsSepaNexty[11];
+       apsu2=atomsSepaNexty[12];
+       apsu3=atomsSepaNexty[13];
+       apsu4=atomsSepaNexty[14];
+       apsu5=atomsSepaNexty[15];
 }
 */
      /* handle left boundary */
@@ -1301,11 +1433,11 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
      }
      if (k>len){   /* all zero */
 	 kL=0;
-	 begsLeftBoun[nykyinen]=0;
+	 begsLeftBouny[nykyinen]=0;
      }
      else{        /*  kL is first non zero  */
 	 kL=k;
-	 begsLeftBoun[nykyinen]=osoittajaNewBleft[kL];
+	 begsLeftBouny[nykyinen]=osoittajaNewBleft[kL];
 	 /*
          update the list of left boundaries
          concatenate the lists of atoms
@@ -1313,8 +1445,8 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
 	 k=kL;
          while (k<=(len-1)){    
 	     curre=osoittajaNewBleft[k]; /* curre is not zero */
-             while (atomsLBounNext[curre]>0){    /* find the end */
-		 curre=atomsLBounNext[curre];
+             while (atomsLBounNexty[curre]>0){    /* find the end */
+		 curre=atomsLBounNexty[curre];
              }
 	     /* find the next non zero */
 	     k=k+1;
@@ -1322,10 +1454,10 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
 		 k=k+1;
              }
            if (k>len){
-	       atomsLBounNext[curre]=0;
+	       atomsLBounNexty[curre]=0;
            }
            else{  /*  found nonzero */
-	       atomsLBounNext[curre]=osoittajaNewBleft[k];
+	       atomsLBounNexty[curre]=osoittajaNewBleft[k];
            }
          }
      }
@@ -1340,11 +1472,11 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
      }
      if (k>len){
 	 kR=0;
-	 begsRighBoun[nykyinen]=0;
+	 begsRighBouny[nykyinen]=0;
      }
      else{
 	 kR=k;
-	 begsRighBoun[nykyinen]=osoittajaNewBright[kR];
+	 begsRighBouny[nykyinen]=osoittajaNewBright[kR];
   
 	 /* update the list of right boundaries */
 	 /* concatenate the lists of atoms */
@@ -1352,8 +1484,8 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
 	 k=kR;
          while (k<=(len-1)){    
 	     curre=osoittajaNewBright[k];        /* curre is not zero */
-             while (atomsRBounNext[curre]>0){    /* find the end */
-		 curre=atomsRBounNext[curre];
+             while (atomsRBounNexty[curre]>0){    /* find the end */
+		 curre=atomsRBounNexty[curre];
              }
 	     /* find the next non zero */
 	     k=k+1;
@@ -1361,16 +1493,16 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
 		 k=k+1;
              }
              if (k>len){
-		 atomsRBounNext[curre]=0;
+		 atomsRBounNexty[curre]=0;
              }
 	     else{  /* found nonzero */
-		 atomsRBounNext[curre]=osoittajaNewBright[k];
+		 atomsRBounNexty[curre]=osoittajaNewBright[k];
              }
          }
      }
   
      /* we move to the next sepaset */
-     nykyinen=begsSepaNext[nykyinen];
+     nykyinen=begsSepaNexty[nykyinen];
      ii=ii+1;
  }
 
@@ -1379,5 +1511,11 @@ if ((leftbeg==2) && (rightbeg==3) && (globapu2==1)){
  apu=1;
  return apu;
 
+ for(i = 0; i <= sepnum; i++) free(res[i]);
+ free(res);
+ free(osoittajaS);
+ free(osoittajaNewBleft);
+ free(osoittajaNewBright);
+
 }
 
